package codicefiscaleinversoproject02;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.HashMap;

public class EstrazioneDatiDaCodiceFiscale extends JFrame implements ActionListener {
    /**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	private JTextField campoCodiceFiscale;
    private JTextField campoNome, campoCognome, campoSesso, campoDataNascita, campoComune;
    private JButton estraiButton;

    // Mappa dei comuni con codici fittizi per semplicità
    private HashMap<String, String> codiciComuni = new HashMap<>();

    public EstrazioneDatiDaCodiceFiscale() {
        setTitle("Estrazione Dati dal Codice Fiscale");
        setSize(400, 300);
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setLocationRelativeTo(null);

        // Creazione della UI
        JPanel pannello = new JPanel(new GridLayout(7, 2, 5, 5));

        pannello.add(new JLabel("Codice Fiscale:"));
        campoCodiceFiscale = new JTextField();
        pannello.add(campoCodiceFiscale);

        pannello.add(new JLabel("Nome:"));
        campoNome = new JTextField();
        campoNome.setEditable(false);
        pannello.add(campoNome);

        pannello.add(new JLabel("Cognome:"));
        campoCognome = new JTextField();
        campoCognome.setEditable(false);
        pannello.add(campoCognome);

        pannello.add(new JLabel("Sesso:"));
        campoSesso = new JTextField();
        campoSesso.setEditable(false);
        pannello.add(campoSesso);

        pannello.add(new JLabel("Data di Nascita:"));
        campoDataNascita = new JTextField();
        campoDataNascita.setEditable(false);
        pannello.add(campoDataNascita);

        pannello.add(new JLabel("Comune di Nascita:"));
        campoComune = new JTextField();
        campoComune.setEditable(false);
        pannello.add(campoComune);

        estraiButton = new JButton("Estrai Dati");
        estraiButton.addActionListener(this);
        pannello.add(estraiButton);

        add(pannello);

        // Aggiunta dei codici fittizi di alcuni comuni
        codiciComuni.put("H501", "ROMA");
        codiciComuni.put("F205", "MILANO");
        codiciComuni.put("F839", "NAPOLI");
        codiciComuni.put("D810", "FROSINONE");
        codiciComuni.put("A123", "ALATRI");
    }

    // Metodo per estrarre i dati personali dal codice fiscale
    private void estraiDati(String codiceFiscale) {
        if (codiceFiscale.length() != 16) {
            JOptionPane.showMessageDialog(this, "Codice Fiscale non valido", "Errore", JOptionPane.ERROR_MESSAGE);
            return;
        }

        // Estrazione del cognome (prime 3 lettere)
        String cognome = estraiNomeOCognome(codiceFiscale.substring(0, 3));
        campoCognome.setText(cognome);

        // Estrazione del nome (secondo gruppo di 3 lettere)
        String nome = estraiNomeOCognome(codiceFiscale.substring(3, 6));
        campoNome.setText(nome);

        // Estrazione dell'anno di nascita
        String anno = "19" + codiceFiscale.substring(6, 8); // Assumiamo 1900-1999 per semplicità

        // Estrazione del mese
        String mese = decodificaMese(codiceFiscale.charAt(8));

        // Estrazione del giorno e sesso
        int giorno = Integer.parseInt(codiceFiscale.substring(9, 11));
        String sesso;
        if (giorno > 40) {
            sesso = "F";
            giorno -= 40; // Il giorno per le donne è > 40
        } else {
            sesso = "M";
        }
        campoSesso.setText(sesso);

        campoDataNascita.setText(giorno + "/" + mese + "/" + anno);

        // Estrazione del comune di nascita
        String codiceComune = codiceFiscale.substring(11, 15);
        String comune = codiciComuni.getOrDefault(codiceComune, "Comune sconosciuto");
        campoComune.setText(comune);
    }

    // Estrazione delle consonanti per formare nome/cognome
    private String estraiNomeOCognome(String codice) {
        return codice.replaceAll("X", ""); // Rimpiazziamo X fittizie
    }

    // Decodifica del mese
    private String decodificaMese(char mese) {
        switch (mese) {
            case 'A': return "01";
            case 'B': return "02";
            case 'C': return "03";
            case 'D': return "04";
            case 'E': return "05";
            case 'H': return "06";
            case 'L': return "07";
            case 'M': return "08";
            case 'P': return "09";
            case 'R': return "10";
            case 'S': return "11";
            case 'T': return "12";
            default: return "??";
        }
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        if (e.getSource() == estraiButton) {
            String codiceFiscale = campoCodiceFiscale.getText();
            estraiDati(codiceFiscale);
        }
    }


}
