package gestionelibreriaproject05;

import javax.swing.*;
import javax.swing.table.DefaultTableModel;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;

public class LibreriaGUI extends JFrame implements ActionListener {
    // Modello dati per la tabella dei libri
    private DefaultTableModel modelloTabella;
    private JTable tabellaLibri;

    // Componenti della UI
    private JTextField campoTitolo, campoAutore, campoPrezzo, campoRicerca;
    private JButton bottoneAggiungi, bottoneRimuovi, bottoneCerca;
    
    // Lista di libri
    private ArrayList<Libro> libreria;

    // Costruttore
    public LibreriaGUI() {
        setTitle("Gestione Libreria");
        setSize(600, 400);
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setLocationRelativeTo(null);

        libreria = new ArrayList<>();

        // Creazione UI
        JPanel pannelloPrincipale = new JPanel(new BorderLayout());
        
        // Pannello per l'inserimento di nuovi libri
        JPanel pannelloInserimento = new JPanel(new GridLayout(4, 2, 5, 5));
        pannelloInserimento.setBorder(BorderFactory.createTitledBorder("Aggiungi Libro"));
        
        pannelloInserimento.add(new JLabel("Titolo:"));
        campoTitolo = new JTextField();
        pannelloInserimento.add(campoTitolo);
        
        pannelloInserimento.add(new JLabel("Autore:"));
        campoAutore = new JTextField();
        pannelloInserimento.add(campoAutore);
        
        pannelloInserimento.add(new JLabel("Prezzo:"));
        campoPrezzo = new JTextField();
        pannelloInserimento.add(campoPrezzo);
        
        bottoneAggiungi = new JButton("Aggiungi Libro");
        bottoneAggiungi.addActionListener(this);
        pannelloInserimento.add(bottoneAggiungi);

        // Pannello per la ricerca di libri
        JPanel pannelloRicerca = new JPanel(new FlowLayout());
        pannelloRicerca.setBorder(BorderFactory.createTitledBorder("Ricerca Libro"));
        campoRicerca = new JTextField(15);
        pannelloRicerca.add(new JLabel("Cerca:"));
        pannelloRicerca.add(campoRicerca);
        bottoneCerca = new JButton("Cerca");
        bottoneCerca.addActionListener(this);
        pannelloRicerca.add(bottoneCerca);

        // Tabella per mostrare i libri
        modelloTabella = new DefaultTableModel(new String[]{"Titolo", "Autore", "Prezzo"}, 0);
        tabellaLibri = new JTable(modelloTabella);
        JScrollPane scrollPane = new JScrollPane(tabellaLibri);
        
        // Bottone per rimuovere il libro selezionato
        bottoneRimuovi = new JButton("Rimuovi Libro");
        bottoneRimuovi.addActionListener(this);

        // Aggiunta dei pannelli al frame
        pannelloPrincipale.add(pannelloInserimento, BorderLayout.NORTH);
        pannelloPrincipale.add(scrollPane, BorderLayout.CENTER);
        pannelloPrincipale.add(pannelloRicerca, BorderLayout.SOUTH);
        add(pannelloPrincipale, BorderLayout.CENTER);
        add(bottoneRimuovi, BorderLayout.SOUTH);
    }

    // Metodo per gestire le azioni dei pulsanti
    @Override
    public void actionPerformed(ActionEvent e) {
        if (e.getSource() == bottoneAggiungi) {
            aggiungiLibro();
        } else if (e.getSource() == bottoneRimuovi) {
            rimuoviLibro();
        } else if (e.getSource() == bottoneCerca) {
            cercaLibro();
        }
    }

    // Metodo per aggiungere un libro
    private void aggiungiLibro() {
        String titolo = campoTitolo.getText();
        String autore = campoAutore.getText();
        String prezzoText = campoPrezzo.getText();
        
        if (titolo.isEmpty() || autore.isEmpty() || prezzoText.isEmpty()) {
            JOptionPane.showMessageDialog(this, "Tutti i campi devono essere compilati", "Errore", JOptionPane.ERROR_MESSAGE);
            return;
        }

        try {
            double prezzo = Double.parseDouble(prezzoText);
            Libro nuovoLibro = new Libro(titolo, autore, prezzo);
            libreria.add(nuovoLibro);
            modelloTabella.addRow(new Object[]{titolo, autore, prezzo});
            campoTitolo.setText("");
            campoAutore.setText("");
            campoPrezzo.setText("");
        } catch (NumberFormatException ex) {
            JOptionPane.showMessageDialog(this, "Il prezzo deve essere un numero valido", "Errore", JOptionPane.ERROR_MESSAGE);
        }
    }

    // Metodo per rimuovere un libro
    private void rimuoviLibro() {
        int rigaSelezionata = tabellaLibri.getSelectedRow();
        if (rigaSelezionata >= 0) {
            modelloTabella.removeRow(rigaSelezionata);
            libreria.remove(rigaSelezionata);
        } else {
            JOptionPane.showMessageDialog(this, "Seleziona un libro da rimuovere", "Errore", JOptionPane.ERROR_MESSAGE);
        }
    }

    // Metodo per cercare un libro
    private void cercaLibro() {
        String ricerca = campoRicerca.getText().toLowerCase();
        modelloTabella.setRowCount(0); // Resetta la tabella
        
        for (Libro libro : libreria) {
            if (libro.getTitolo().toLowerCase().contains(ricerca) || libro.getAutore().toLowerCase().contains(ricerca)) {
                modelloTabella.addRow(new Object[]{libro.getTitolo(), libro.getAutore(), libro.getPrezzo()});
            }
        }
    }

    // Classe interna Libro
    static class Libro {
        private String titolo;
        private String autore;
        private double prezzo;

        public Libro(String titolo, String autore, double prezzo) {
            this.titolo = titolo;
            this.autore = autore;
            this.prezzo = prezzo;
        }

        public String getTitolo() {
            return titolo;
        }

        public String getAutore() {
            return autore;
        }

        public double getPrezzo() {
            return prezzo;
        }
    }

    // Metodo principale per avviare l'applicazione
    public static void main(String[] args) {

    }
}
